/**
******************************************************************************
* @file    main_for_TO.h
* @author  _KEMET, Ltd
* @date    March 2018
* @version Release 1.0.0
* @copyright (c) 2018 _KEMET, Ltd
* @brief   Function prototypes and initialization macros for example code
******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>
   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim
******************************************************************************
*/
/* Includes ------------------------------------------------------------------*/
#include "IRPyro_API_multi_device_layer.h"

/* USER DEFINED MACROS TO SET DEFAULT VALUES */
/* Initialization Macros ---------------------------------------------------- */
/*
    .AFE_register.S7_S0   = 0,                 // Sample rate 1 ms
    .AFE_register.LP      = LOW_POWER_DISABLE, // Low power disabled
    .AFE_register.HP      = HP_DISABLE,        // High pass filter disabled
    .AFE_register.C_LP    = LOW_PASS_180,      // Low pass filter selected to 180 Hz
    .AFE_register.CLK_OUT = CLK_ENABLE,        // Internal clock output ENABLED
    .AFE_register.SYNC    = MASTER,            // Device set to master
    .AFE_register.TEMP    = TEMP_DISABLE,      // Temperature detection off
    .AFE_register.INT     = INT_ENABLE,        // Asserted LOW when data ready
*/
#define AFE_INIT_DEFAULT(X) AFE_reg_type X = { \
  .S7_S0   = 0,                 \
  .LP      = LOW_POWER_DISABLE, \
  .HP      = HP_ENABLE,         \
  .C_LP    = LOW_PASS_180,      \
  .CLK_OUT = CLK_ENABLE,        \
  .SYNC    = MASTER,            \
  .TEMP    = TEMP_DISABLE,      \
  .INT     = INT_ENABLE         \
}
/*
    .status_bit                = CH_ENABLE,      // Channel enabled
    .Feedback_transconductance = TCONDUCT_1_2T,  // Gain to 1.2T
    .High_pass_filter_setting  = HIGH_PASS_1HZ,  // High pass filter to 1Hz
    .Feedback_cap              = FEEDBACK_50_20, // Feedback cap to 50 fF

*/
#define CCP_INIT_DEFAULT(X) CCP_reg_type X = { \
  .status_bit                = CH_ENABLE,      \
  .Feedback_transconductance = TCONDUCT_1_2T,  \
  .High_pass_filter_setting  = HIGH_PASS_1HZ,  \
  .Feedback_cap              = FEEDBACK_50_20  \
}

/*
    .UHT          = 0xFF,
    .ULT          = 0xFF,
    .LHT          = 0x00,
    .LLT          = 0x00,
    .WT_Threshold = 0x10,
    .DP0_DP2      = REF_CH_0,
    .CH0_CH2      = SEL_CH_2,
    .ST           = SLEEP_MODE_ONE_CH,

*/
#define WUP_INIT_DEFAULT(X) WUP_reg_type X ={ \
  .UHT = MAX_WUP_THRESHOLD, .ULT = MAX_WUP_THRESHOLD, \
  .LHT = MIN_WUP_THRESHOLD, .LLT = MIN_WUP_THRESHOLD, \
  .WT_Threshold = DEFAULT_NO_EVENTS, \
  .DP0_DP2 = REF_CH_2, \
  .CH0_CH2 = SEL_CH_2, \
  .ST = SLEEP_MODE_ONE_CH \
}

/*
  Macro with default values
  */
#define IRPyro_INIT_DEFAULT(X) IRPyro_sensor_device_type X = { \
           .CS_Port = 2, \
           .INT_Port = 1, \
           .CS_Pin = 1, \
           .INT_Pin= 4, \
           .address = 0x65, \
            number_of_active_channels= 1 \
}
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
